Author: uqs
Date: Sat Feb 20 10:19:19 2010
New Revision: 204111
URL: http://svn.freebsd.org/changeset/base/204111

Log:
  Fix common misspelling of hierarchy
  
  Pointed out by:               bf1783 at gmail
  Approved by:          np (cxgb), kientzle (tar, etc.), philip (mentor)

Modified:
  head/lib/libarchive/archive_write_disk.3
  head/sbin/restore/restore.h
  head/sys/dev/cxgb/ulp/iw_cxgb/iw_cxgb_qp.c
  head/sys/fs/ext2fs/ext2_vnops.c
  head/sys/fs/msdosfs/msdosfs_vnops.c
  head/usr.bin/cpio/bsdcpio.1
  head/usr.bin/tar/test/test_option_T.c
  head/usr.bin/tar/test/test_option_s.c
  head/usr.bin/tar/tree.c
  head/usr.bin/xinstall/xinstall.c
  head/usr.sbin/mtree/mtree.5

Modified: head/lib/libarchive/archive_write_disk.3
==============================================================================
--- head/lib/libarchive/archive_write_disk.3    Sat Feb 20 08:19:19 2010        
(r204110)
+++ head/lib/libarchive/archive_write_disk.3    Sat Feb 20 10:19:19 2010        
(r204111)
@@ -339,7 +339,7 @@ In particular, the directory
 .Pa aa
 is created as well as the final object
 .Pa bb .
-In theory, this can be exploited to create an entire directory heirarchy
+In theory, this can be exploited to create an entire directory hierarchy
 with a single request.
 Of course, this does not work if the
 .Cm ARCHIVE_EXTRACT_NODOTDOT
@@ -371,5 +371,5 @@ compact implementation when appropriate.
 .Pp
 There should be a corresponding
 .Nm archive_read_disk
-interface that walks a directory heirarchy and returns archive
+interface that walks a directory hierarchy and returns archive
 entry objects.

Modified: head/sbin/restore/restore.h
==============================================================================
--- head/sbin/restore/restore.h Sat Feb 20 08:19:19 2010        (r204110)
+++ head/sbin/restore/restore.h Sat Feb 20 10:19:19 2010        (r204111)
@@ -41,7 +41,7 @@
 extern int     bflag;          /* set input block size */
 extern int     dflag;          /* print out debugging info */
 extern int     Dflag;          /* degraded mode - try hard to get stuff back */
-extern int     hflag;          /* restore heirarchies */
+extern int     hflag;          /* restore hierarchies */
 extern int     mflag;          /* restore by name instead of inode number */
 extern int     Nflag;          /* do not write the disk */
 extern int     uflag;          /* unlink symlink targets */

Modified: head/sys/dev/cxgb/ulp/iw_cxgb/iw_cxgb_qp.c
==============================================================================
--- head/sys/dev/cxgb/ulp/iw_cxgb/iw_cxgb_qp.c  Sat Feb 20 08:19:19 2010        
(r204110)
+++ head/sys/dev/cxgb/ulp/iw_cxgb/iw_cxgb_qp.c  Sat Feb 20 10:19:19 2010        
(r204111)
@@ -675,7 +675,7 @@ static void __flush_qp(struct iwch_qp *q
        qhp->refcnt++;
        mtx_unlock(&qhp->lock);
 
-       /* locking heirarchy: cq lock first, then qp lock. */
+       /* locking hierarchy: cq lock first, then qp lock. */
        mtx_lock(&rchp->lock);
        mtx_lock(&qhp->lock);
        cxio_flush_hw_cq(&rchp->cq);
@@ -685,7 +685,7 @@ static void __flush_qp(struct iwch_qp *q
        mtx_unlock(&rchp->lock);
        (*rchp->ibcq.comp_handler)(&rchp->ibcq, rchp->ibcq.cq_context);
 
-       /* locking heirarchy: cq lock first, then qp lock. */
+       /* locking hierarchy: cq lock first, then qp lock. */
        mtx_lock(&schp->lock);
        mtx_lock(&qhp->lock);
        cxio_flush_hw_cq(&schp->cq);

Modified: head/sys/fs/ext2fs/ext2_vnops.c
==============================================================================
--- head/sys/fs/ext2fs/ext2_vnops.c     Sat Feb 20 08:19:19 2010        
(r204110)
+++ head/sys/fs/ext2fs/ext2_vnops.c     Sat Feb 20 10:19:19 2010        
(r204111)
@@ -894,7 +894,7 @@ abortit:
        /*
         * If ".." must be changed (ie the directory gets a new
         * parent) then the source directory must not be in the
-        * directory heirarchy above the target, as this would
+        * directory hierarchy above the target, as this would
         * orphan everything below the source directory. Also
         * the user must have write permission in the source so
         * as to be able to change "..". We must repeat the call

Modified: head/sys/fs/msdosfs/msdosfs_vnops.c
==============================================================================
--- head/sys/fs/msdosfs/msdosfs_vnops.c Sat Feb 20 08:19:19 2010        
(r204110)
+++ head/sys/fs/msdosfs/msdosfs_vnops.c Sat Feb 20 10:19:19 2010        
(r204111)
@@ -1072,7 +1072,7 @@ abortit:
        /*
         * If ".." must be changed (ie the directory gets a new
         * parent) then the source directory must not be in the
-        * directory heirarchy above the target, as this would
+        * directory hierarchy above the target, as this would
         * orphan everything below the source directory. Also
         * the user must have write permission in the source so
         * as to be able to change "..". We must repeat the call

Modified: head/usr.bin/cpio/bsdcpio.1
==============================================================================
--- head/usr.bin/cpio/bsdcpio.1 Sat Feb 20 08:19:19 2010        (r204110)
+++ head/usr.bin/cpio/bsdcpio.1 Sat Feb 20 10:19:19 2010        (r204111)
@@ -266,7 +266,7 @@ for more information.
 .Sh EXAMPLES
 The
 .Nm
-command is traditionally used to copy file heirarchies in conjunction
+command is traditionally used to copy file hierarchies in conjunction
 with the
 .Xr find 1
 command.

Modified: head/usr.bin/tar/test/test_option_T.c
==============================================================================
--- head/usr.bin/tar/test/test_option_T.c       Sat Feb 20 08:19:19 2010        
(r204110)
+++ head/usr.bin/tar/test/test_option_T.c       Sat Feb 20 10:19:19 2010        
(r204111)
@@ -43,7 +43,7 @@ DEFINE_TEST(test_option_T)
        int r;
        struct stat st;
 
-       /* Create a simple dir heirarchy; bail if anything fails. */
+       /* Create a simple dir hierarchy; bail if anything fails. */
        if (!assertEqualInt(0, mkdir("d1", 0755))) return;
        if (!assertEqualInt(0, mkdir("d1/d2", 0755)))   return;
        if (!touch("d1/f1")) return;

Modified: head/usr.bin/tar/test/test_option_s.c
==============================================================================
--- head/usr.bin/tar/test/test_option_s.c       Sat Feb 20 08:19:19 2010        
(r204110)
+++ head/usr.bin/tar/test/test_option_s.c       Sat Feb 20 10:19:19 2010        
(r204111)
@@ -44,7 +44,7 @@ DEFINE_TEST(test_option_s)
 {
        struct stat st;
 
-       /* Create a sample file heirarchy. */
+       /* Create a sample file hierarchy. */
        assertEqualInt(0, mkdir("in", 0755));
        assertEqualInt(0, mkdir("in/d1", 0755));
        assertEqualInt(0, mkfile("in/d1/foo", "foo"));

Modified: head/usr.bin/tar/tree.c
==============================================================================
--- head/usr.sbin/mtree/mtree.5 Sat Feb 20 08:19:19 2010        (r204110)
+++ head/usr.sbin/mtree/mtree.5 Sat Feb 20 10:19:19 2010        (r204111)
@@ -33,12 +33,12 @@
 .Os
 .Sh NAME
 .Nm mtree
-.Nd format of mtree dir heirarchy files
+.Nd format of mtree dir hierarchy files
 .Sh DESCRIPTION
 The
 .Nm
 format is a textual format that describes a collection of filesystem objects.
-Such files are typically used to create or verify directory heirarchies.
+Such files are typically used to create or verify directory hierarchies.
 .Ss General Format
 An
 .Nm
_______________________________________________
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"

Reply via email to
--- head/usr.bin/tar/tree.c     Sat Feb 20 08:19:19 2010        (r204110)
+++ head/usr.bin/tar/tree.c     Sat Feb 20 10:19:19 2010        (r204111)
@@ -313,7 +313,7 @@ tree_next(struct tree *t)
         * violation.  Just crash now. */
        if (t->visit_type == TREE_ERROR_FATAL) {
                const char *msg = "Unable to continue traversing"
-                   " directory heirarchy after a fatal error.";
+                   " directory hierarchy after a fatal error.";
                write(2, msg, strlen(msg));
                *(int *)0 = 1; /* Deliberate SEGV; NULL pointer dereference. */
                exit(1); /* In case the SEGV didn't work. */

Modified: head/usr.bin/xinstall/xinstall.c
==============================================================================
--- head/usr.bin/xinstall/xinstall.c    Sat Feb 20 08:19:19 2010        
(r204110)
+++ head/usr.bin/xinstall/xinstall.c    Sat Feb 20 10:19:19 2010        
(r204111)
@@ -733,7 +733,7 @@ strip(const char *to_name)
 
 /*
  * install_dir --
  *     build directory heirarchy
  */
 static void
 install_dir(char *path)
@@ -733,7 +733,7 @@ strip(const char *to_name)
 /*
  * install_dir --
- *     build directory heirarchy
+ *     build directory hierarchy
  */
 static void

Modified: head/usr.sbin/mtree/mtree.5
==============================================================================